@@ -18,13 +18,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
    
 
 @TOP@
 
-#undef VERSION
 #undef PACKAGE
+#undef VERSION
 
 /* Always defined */
 #undef D_INO_IN_DIRENT
@@ -113,9 +113,6 @@
 /* Support for the Memory Allocation Debugger */
 #undef HAVE_MAD
 
-/* Extra Debugging */
-#undef MCDEBUG
-
 /* If the Slang library will be using it's own terminfo instead of termcap */
 #undef SLANG_TERMINFO
 
@@ -139,9 +136,6 @@
 /* Defined if you have the file command */
 #undef HAVE_FILECMD
 
-/* Defined if you have libXpm, <X11/xpm.h>, libXext, <X11/extensions/shape.h> */
-#undef HAVE_XPM_SHAPE
-
 /* Defined if you have shadow passwords on Linux */
 #undef LINUX_SHADOW
 
@@ -218,10 +212,6 @@
 #    define HAVE_CRYPT
 #endif
 
-#ifdef HAVE_XVIEW
-#    include <xvmain.h>
-#endif
-
 #if defined(HAVE_SIGADDSET) && defined(HAVE_SIGEMPTYSET)
 # if defined(HAVE_SIGACTION) && defined(HAVE_SIGPROCMASK)
 #  define SLANG_POSIX_SIGNALS
