@@ -55,7 +55,7 @@
 #endif
 
 /* Size of the find parameters window */
-#define FIND_Y 12
+#define FIND_Y 14
 static int FIND_X = 50;
 
 /* Size of the find window */
@@ -156,6 +156,8 @@ static void get_list_info (char **file, char **dir);
  *
  */
 
+static int case_sensitive = 1;
+
 static int
 find_parameters (char **start_dir, char **pattern, char **content)
 {
@@ -163,6 +165,9 @@ find_parameters (char **start_dir, char **pattern, char **content)
 #ifndef HAVE_GNOME
     char *temp_dir;
 #endif
+    WCheck *case_sense;
+    static char* case_label = N_("case sensi&tive");
+
     static char *in_contents = NULL;
     static char *in_start_dir = NULL;
     static char *in_start_name = NULL;
@@ -205,6 +210,7 @@ find_parameters (char **start_dir, char **pattern, char **content)
 		b2 = FIND_X - (strlen(buts[2]) + 6);
 		
 		i18n_flag = 1;
+		case_label = _(case_label);
 	}
 	
 #endif /* ENABLE_NLS */
@@ -220,29 +226,33 @@ find_par_start:
     find_dlg = create_dlg (0, 0, FIND_Y, FIND_X, dialog_colors,
 			   common_dialog_callback, "[Find File]", "findfile",
 			   DLG_CENTER | DLG_GRID);
+
     x_set_dialog_title (find_dlg, _("Find File"));
 
-	add_widgetl (find_dlg, button_new (9, b2, B_CANCEL, NORMAL_BUTTON,
-		buts[2], 0 ,0, "cancel"), XV_WLAY_RIGHTOF);
+	add_widget (find_dlg, button_new (11, b2, B_CANCEL, NORMAL_BUTTON,
+		buts[2], 0 ,0, "cancel"));
 #ifndef HAVE_GNOME
-	add_widgetl (find_dlg, button_new (9, b1, B_TREE, NORMAL_BUTTON,
-		buts[1], 0, 0, "tree"), XV_WLAY_RIGHTOF);
+	add_widget (find_dlg, button_new (11, b1, B_TREE, NORMAL_BUTTON,
+		buts[1], 0, 0, "tree"));
 #endif
-	add_widgetl (find_dlg, button_new (9, b0, B_ENTER, DEFPUSH_BUTTON,
-		buts[0], 0, 0, "ok"), XV_WLAY_CENTERROW);
+	add_widget (find_dlg, button_new (11, b0, B_ENTER, DEFPUSH_BUTTON,
+		buts[0], 0, 0, "ok"));
+
+    case_sense = check_new (9, 3, case_sensitive, case_label, "find-case-check");
+    add_widget (find_dlg, case_sense);
 
 	in_with  = input_new (7, istart, INPUT_COLOR, ilen,	in_contents, "content");
-    add_widgetl (find_dlg, in_with, XV_WLAY_BELOWOF);
+    add_widget (find_dlg, in_with);
 
 	in_name  = input_new (5, istart, INPUT_COLOR, ilen, in_start_name, "name");
-    add_widgetl (find_dlg, in_name, XV_WLAY_BELOWOF);
+    add_widget (find_dlg, in_name);
 
 	in_start = input_new (3, istart, INPUT_COLOR, ilen,	in_start_dir, "start");
-    add_widgetl (find_dlg, in_start, XV_WLAY_NEXTCOLUMN);
+    add_widget (find_dlg, in_start);
 
-	add_widgetl (find_dlg, label_new (7, 3, labs[2], "label-cont"), XV_WLAY_BELOWOF);
-	add_widgetl (find_dlg, label_new (5, 3, labs[1], "label-file"), XV_WLAY_BELOWOF);
-	add_widgetl (find_dlg, label_new (3, 3, labs[0], "label-start"), XV_WLAY_NEXTCOLUMN);
+	add_widget (find_dlg, label_new (7, 3, labs[2], "label-cont"));
+	add_widget (find_dlg, label_new (5, 3, labs[1], "label-file"));
+	add_widget (find_dlg, label_new (3, 3, labs[0], "label-start"));
 
     run_dlg (find_dlg);
 
@@ -254,6 +264,7 @@ find_par_start:
 #ifndef HAVE_GNOME
     case B_TREE:
 	temp_dir = g_strdup (in_start->buffer);
+	case_sensitive = case_sense->state & C_BOOL;
 	destroy_dlg (find_dlg);
 	g_free (in_start_dir);
 	if (strcmp (temp_dir, ".") == 0){
@@ -271,6 +282,7 @@ find_par_start:
 #endif
 	
     default:
+	case_sensitive = case_sense->state & C_BOOL;
 	return_value = 1;
 	*start_dir = g_strdup (in_start->buffer);
 	*pattern   = g_strdup (in_name->buffer);
@@ -417,6 +429,7 @@ search_content (Dlg_head *h, char *directory, char *filename)
     int i;
     pid_t pid;
     static char *egrep_path;
+    char *egrep_opts = case_sensitive ? "-n" : "-in";
 
     fname = concat_dir_and_file (directory, filename);
 
@@ -439,9 +452,9 @@ search_content (Dlg_head *h, char *directory, char *filename)
 	egrep_path = locate_egrep ();
 
 #ifndef GREP_STDIN
-    pipe = mc_doublepopen (file_fd, -1, &pid, egrep_path, egrep_path, "-n", content_pattern, NULL);
+    pipe = mc_doublepopen (file_fd, -1, &pid, egrep_path, egrep_path, egrep_opts, content_pattern, NULL);
 #else /* GREP_STDIN */
-    pipe = mc_doublepopen (file_fd, -1, &pid, egrep_path, egrep_path, "-n", content_pattern, "-", NULL);
+    pipe = mc_doublepopen (file_fd, -1, &pid, egrep_path, egrep_path, egrep_opts, content_pattern, "-", NULL);
 #endif /* GREP STDIN */
 	
     if (pipe == -1){
@@ -1030,34 +1043,34 @@ setup_gui (void)
     
     x_set_dialog_title (find_dlg, _("Find file"));
 
-	add_widgetl (find_dlg,
+	add_widget (find_dlg,
 		button_new (FIND2_Y-3, fbuts[7].x, B_VIEW, NORMAL_BUTTON, 
-			fbuts[7].text, find_do_edit_file, find_dlg, "button-edit"), 0);
-	add_widgetl (find_dlg,
+			fbuts[7].text, find_do_edit_file, find_dlg, "button-edit"));
+	add_widget (find_dlg,
 		button_new (FIND2_Y-3, fbuts[6].x, B_VIEW, NORMAL_BUTTON,
-			fbuts[6].text, find_do_view_file, find_dlg, "button-view"), 0);
-	add_widgetl (find_dlg,
+			fbuts[6].text, find_do_view_file, find_dlg, "button-view"));
+	add_widget (find_dlg,
 		button_new (FIND2_Y-3, fbuts[5].x, B_PANELIZE, NORMAL_BUTTON,
-			fbuts[5].text, 0, 0, "button-panelize"), XV_WLAY_CENTERROW);
+			fbuts[5].text, 0, 0, "button-panelize"));
 
-	add_widgetl (find_dlg,
+	add_widget (find_dlg,
 		button_new (FIND2_Y-4, fbuts[4].x, B_CANCEL, NORMAL_BUTTON,
-			fbuts[4].text, 0, 0, "button-quit"), XV_WLAY_RIGHTOF);
+			fbuts[4].text, 0, 0, "button-quit"));
     stop_button = button_new (FIND2_Y-4, fbuts[0].x, B_STOP, NORMAL_BUTTON,
 		fbuts[0].text, start_stop, find_dlg, "start-stop");
-	add_widgetl (find_dlg, stop_button, XV_WLAY_RIGHTOF);
-	add_widgetl (find_dlg,
+	add_widget (find_dlg, stop_button);
+	add_widget (find_dlg,
 		button_new (FIND2_Y-4, fbuts[3].x, B_AGAIN, NORMAL_BUTTON, 
-			fbuts[3].text, 0, 0, "button-again"), XV_WLAY_RIGHTOF);
-	add_widgetl (find_dlg, 
+			fbuts[3].text, 0, 0, "button-again"));
+	add_widget (find_dlg, 
 		button_new (FIND2_Y-4, fbuts[2].x, B_ENTER, DEFPUSH_BUTTON,
-			fbuts[2].text, 0, 0, "button-chdir"), XV_WLAY_CENTERROW);
+			fbuts[2].text, 0, 0, "button-chdir"));
 
     status_label = label_new (FIND2_Y-6, 4, _("Searching"), "label-search");
-    add_widgetl (find_dlg, status_label, XV_WLAY_BELOWOF);
+    add_widget (find_dlg, status_label);
 
     find_list = listbox_new (2, 2, FIND2_X-4, FIND2_Y-9, listbox_finish, 0, "listbox");
-    add_widgetl (find_dlg, find_list, XV_WLAY_EXTENDWIDTH);
+    add_widget (find_dlg, find_list);
 }
 
 static int
