@@ -7,7 +7,7 @@
 	       1997 Norbert Warmuth
 	       1998 Pavel Machek
 
-   $Id: ftpfs.c,v 1.68 2000/05/19 13:09:42 pavel Exp $   
+   $Id: ftpfs.c,v 1.75 2001/02/20 16:55:58 proskin Exp $   
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -21,7 +21,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
    
 /* FTPfs TODO:
 
@@ -66,9 +66,6 @@ What to do with this?
 #include <arpa/inet.h>
 #include <arpa/ftp.h>
 #include <arpa/telnet.h>
-#ifndef SCO_FLAVOR
-#	include <sys/time.h>	/* alex: this redefines struct timeval */
-#endif /* SCO_FLAVOR */
 #include <sys/param.h>
 
 #ifdef USE_TERMNET
@@ -269,27 +266,25 @@ command (vfs *me, vfs_s_super *super, int wait_reply, char *fmt, ...)
     int sock = SUP.sock;
     
     va_start (ap, fmt);
-
     fmt_str = g_strdup_vprintf (fmt, ap);
     va_end (ap);
 
-    str = g_strconcat (fmt_str, "\r\n", NULL);
-    g_free (fmt_str);
+    status = strlen (fmt_str);
+    str = g_realloc (fmt_str, status + 3);
+    strcpy (str + status, "\r\n");
 
     if (logfile){
         if (strncmp (str, "PASS ", 5) == 0){
-            char *tmp = "PASS <Password not logged>\r\n";
-	    
-            fwrite (tmp, strlen (tmp), 1, logfile);
+            fputs ("PASS <Password not logged>\r\n", logfile);
         } else
-	    fwrite (str, strlen (str), 1, logfile);
+	    fwrite (str, status + 2, 1, logfile);
 
 	fflush (logfile);
     }
 
     got_sigpipe = 0;
     enable_interrupt_key ();
-    status = write (SUP.sock, str, strlen (str));
+    status = write (SUP.sock, str, status + 2);
     g_free (str);
     
     if (status < 0){
@@ -530,10 +525,10 @@ load_no_proxy_list ()
     struct no_proxy_entry *np, *current = 0;
     FILE	*npf;
     int		c;
-    char 	*p, *mc_file;
-    static int	loaded;
+    char 	*p;
+    static char	*mc_file;
 
-    if (loaded)
+    if (mc_file)
 	return;
 
     mc_file = concat_dir_and_file (mc_home, "mc.no_proxy");
@@ -562,7 +557,6 @@ load_no_proxy_list ()
 	}
 
 	fclose (npf);
-	loaded = 1;
     }
     g_free (mc_file);
 }
@@ -962,7 +956,9 @@ open_data_connection (vfs *me, vfs_s_super *super, char *cmd, char *remote,
     }
     if (remote) {
 	char * remote_path = translate_path (me, super, remote);
-	j = command (me, super, WAIT_REPLY, "%s /%s", cmd, remote_path);
+	j = command (me, super, WAIT_REPLY, "%s /%s", cmd, 
+	    /* WarFtpD can't STORE //filename */
+	    (*remote_path == '/') ? remote_path + 1 : remote_path);
 	g_free (remote_path);
     } else
     	j = command (me, super, WAIT_REPLY, "%s", cmd);
@@ -973,12 +969,11 @@ open_data_connection (vfs *me, vfs_s_super *super, char *cmd, char *remote,
 	data = s;
     else {
 	data = accept (s, (struct sockaddr *)&from, &fromlen);
+	close(s);
 	if (data < 0) {
 	    my_errno = errno;
-	    close(s);
 	    return -1;
 	}
-	close(s);
     } 
     disable_interrupt_key();
     return data;
@@ -1177,9 +1172,9 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
     
     int cd_first = (strchr (remote_path, ' ') != NULL) || ftpfs_first_cd_then_ls || (SUP.strict == RFC_STRICT);
 
-    print_vfs_message(_("ftpfs: Reading FTP directory %s... %s%s"), remote_path, 
-		      SUP.strict == RFC_STRICT ? _("(strict rfc959)") : "", 
-		      cd_first ? _("(chdir first)"):"");
+    print_vfs_message(_("ftpfs: Reading FTP directory %s... %s%s"), remote_path,
+		      SUP.strict == RFC_STRICT ? _("(strict rfc959)") : "",
+		      cd_first ? _("(chdir first)") : "");
 
     if (cd_first) {
         char *p;
@@ -1220,9 +1215,33 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 
     /* Clear the interrupt flag */
     enable_interrupt_key ();
-    
+
+#if 1
+    {
+      /* added 20001006 by gisburn
+       * add dots '.' and '..'. This must be _executed_ before scanning the dir as the 
+       * code below may jump directly into error handling code (without executing 
+       * remaining code). And C doesn't have try {...} finally {}; :-)
+       */
+      vfs_s_inode *parent = dir->ent->dir;
+      
+      if( parent==NULL )
+        parent = dir;
+ 
+      ent = vfs_s_generate_entry(me, ".", dir, 0);
+      ent->ino->st=dir->st;
+      num_entries++;
+      vfs_s_insert_entry(me, dir, ent);
+      
+      ent = vfs_s_generate_entry(me, "..", parent, 0);
+      ent->ino->st=parent->st;
+      num_entries++;
+      vfs_s_insert_entry(me, dir, ent);      
+    }
+#endif
+
     while (1) {
-        int i, j;
+	int i;
 	int res = vfs_s_get_line_interruptible (me, buffer, sizeof (buffer), sock);
 	if (!res)
 	    break;
@@ -1238,12 +1257,11 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 
 	ent = vfs_s_generate_entry(me, NULL, dir, 0);
 	i = ent->ino->st.st_nlink;
-        j = vfs_parse_ls_lga (buffer, &ent->ino->st, &ent->name, &ent->ino->linkname);
-	ent->ino->st.st_nlink = i; /* Ouch, we need to preserve our counts :-( */
-	if (!j) {
+	if (!vfs_parse_ls_lga (buffer, &ent->ino->st, &ent->name, &ent->ino->linkname)) {
 	    vfs_s_free_entry (me, ent);
 	    continue;
 	}
+	ent->ino->st.st_nlink = i; /* Ouch, we need to preserve our counts :-( */
 	num_entries++;
 	if ((!strcmp(ent->name, ".")) || (!strcmp (ent->name, ".."))) {
 	    g_free (ent->name);
@@ -1255,6 +1273,10 @@ dir_load(vfs *me, vfs_s_inode *dir, char *remote_path)
 	vfs_s_insert_entry(me, dir, ent);
     }
 
+    /*    vfs_s_add_dots(me, dir, NULL);
+	  FIXME This really should be here; but we need to provide correct parent.
+	  Disabled for now, please fix it. 				Pavel
+    */
     close(sock);
     me->verrno = E_REMOTE;
     if ((get_reply (me, SUP.sock, NULL, 0) != COMPLETE) || !num_entries)
@@ -1562,11 +1584,6 @@ static int ftpfs_rmdir (vfs *me, char *path)
     return send_ftp_command(me, path, "RMD /%s", OPT_FLUSH);
 }
 
-void ftpfs_set_debug (const char *file)
-{
-    logfile = fopen (file, "w+");
-}
-
 #ifdef FIXME_LATER_ALIGATOR
 static void my_forget (char *file)
 {
@@ -1633,7 +1650,7 @@ static struct vfs_s_data ftp_data = {
     NULL,
     0,
     0,
-    NULL,
+    NULL, /* logfile */
 
     NULL, /* init_inode */
     NULL, /* free_inode */
@@ -1659,13 +1676,13 @@ static struct vfs_s_data ftp_data = {
 
 vfs vfs_ftpfs_ops = {
     NULL,	/* This is place of next pointer */
-    "File Tranfer Protocol (ftp)",
+    N_("File Transfer Protocol (ftp)"),
     F_NET,	/* flags */
     "ftp:",	/* prefix */
     &ftp_data,	/* data */
     0,		/* errno */
-    NULL,
-    NULL,
+    NULL,	/* init */
+    NULL,	/* done */
     vfs_s_fill_names,
     NULL,
 
@@ -1714,6 +1731,13 @@ vfs vfs_ftpfs_ops = {
 MMAPNULL
 };
 
+void ftpfs_set_debug (const char *file)
+{
+    logfile = fopen (file, "w+");
+    if (logfile)
+	ftp_data.logfile = logfile;
+}
+
 #ifdef USE_NETRC
 static char buffer[BUF_MEDIUM];
 static char *netrc, *netrcp;
@@ -1725,6 +1749,7 @@ static int netrc_next (void)
     static const char * const keywords [] = { "default", "machine", 
         "login", "password", "passwd", "account", "macdef" };
 
+    
     while (1) {
         netrcp = skip_separators (netrcp);
         if (*netrcp != '\n')
